==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/ja.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "使用状況レポート",
    "Last report sent on: {on}" : "最新のレポート送信時刻: {on}",
    "An error occurred while sending your report." : "レポート送信中にエラーが発生しました。",
    "App list <em>(for each app: name, version, enabled status)</em>" : "アプリ一覧 <em>(各アプリ: 名前、バージョン、有効か無効か)</em>",
    "Database environment <em>(type, version, database size)</em>" : "データベース環境 <em>(種類、バージョン、データベースサイズ)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "暗号化情報 <em>(有効かどうか、デフォルトモジュールの種類)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "共有の数 <em>(種類ごとならびにパーミッション設定)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP環境 <em>(バージョン、メモリ上限、最大実行時間、最大ファイルサイズ)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "サーバーインスタンスの詳細 <em>(バージョン、memcacheの利用、locking/previews/avatarsの状況)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "統計（ファイル数、ユーザー数、タイプごとのストレージ数、コメント、タグ）",
    "Help improve Nextcloud" : "Nextcloudの改善を助けてください",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Nextcloudの改善に役立てるため、設定ならびに使用状況の一部を匿名化したデータを、提供していただけないでしょうか？ この設定は、いつでも管理者設定から無効にできます。",
    "Not now" : "あとで",
    "Send usage" : "使用状況を送信",
    "Never" : "使用しない",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "設定ならびに使用状況に関する一部のデータを送信していただくと、Nextcloudの改善に役立ちます。",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "プライバシー情報について慎重に取り扱います。データは、明示的にオンを選択しなければデフォルトでは送信されませんし、オンにした場合でも、まず匿名化された上にどのデータを送信するか選択することができます。レポートを受け取ったら、古いデータは削除されます。レポートの削除を受け取ったら現在あるサーバー上のすべてのデータを削除します。",
    "Send new report now" : "新しい使用状況レポートを送信",
    "Send usage survey monthly" : "使用状況レポートを毎月送信する",
    "Data to send" : "送信データ",
    "Last report sent on: %s" : "最新のレポート送信時刻: %s",
    "Last report" : "最新のレポート"
},
"nplurals=1; plural=0;");

==> nextcloud-21.0.1-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/ja.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "最新のレポート送信時刻: {on}",
    "An error occurred while sending your report." : "レポート送信中にエラーが発生しました。",
    "App list <em>(for each app: name, version, enabled status)</em>" : "アプリ一覧 <em>(各アプリ: 名前、バージョン、有効か無効か)</em>",
    "Database environment <em>(type, version, database size)</em>" : "データベース環境 <em>(種類、バージョン、データベースサイズ)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "暗号化情報 <em>(有効かどうか、デフォルトモジュールの種類)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "共有の数 <em>(種類ごとならびにパーミッション設定)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP環境 <em>(バージョン、メモリ上限、最大実行時間、最大ファイルサイズ)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "サーバーインスタンスの詳細 <em>(バージョン、memcacheの利用、locking/previews/avatarsの状況)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "統計（ファイル数、ユーザー数、タイプごとのストレージ数、コメント、タグ）",
    "Usage survey" : "使用状況レポート",
    "Help improve Nextcloud" : "Nextcloudの改善を手伝ってください",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Nextcloudの改善に役立てるため、設定ならびに使用状況の一部を匿名化したデータを、提供していただけないでしょうか？ この設定は、いつでも管理者設定から無効にできます。",
    "Not now" : "あとで",
    "Send usage" : "使用状況を送信",
    "Never" : "使用しない",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Nextcloudの改善に役立つ匿名データをNextcloudに送信します。",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "匿名化されたデータを Nextcloud に送信して、Nextcloud の改善に役立てるようにします。\nあなたが Nextcloud に送信されるデータを常に完全に制御でき、いつでも無効にすることができます",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "設定ならびに使用状況に関する一部のデータを送信していただくと、Nextcloudの改善に役立ちます。",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "プライバシー情報について慎重に取り扱います。データは、明示的にオンを選択しなければデフォルトでは送信されませんし、オンにした場合でも、まず匿名化された上にどのデータを送信するか選択することができます。レポートを受け取ったら、古いデータは削除されます。レポートの削除を受け取ったら現在あるサーバー上のすべてのデータを削除します。",
    "Send new report now" : "新しい使用状況レポートを送信",
    "Send usage survey monthly" : "使用状況レポートを毎月送信する",
    "Data to send" : "送信データ",
    "Last report sent on: %s" : "最新のレポート送信時刻: %s",
    "Last report" : "最新のレポート"
},
"nplurals=1; plural=0;");
